@@ -10,9 +10,7 @@
 #'   for confidence interval type.
 #' @param input_time_unit (`string`)\cr `day`, `week`, `month`, or `year` (default)
 #'   indicating time unit for data input.
-#' @param num_pt_year (`numeric`)\cr number of patient-years to use when calculating adverse event rates.
-#' @param time_unit_input `r lifecycle::badge("deprecated")` Please use the `input_time_unit` argument instead.
-#' @param time_unit_output `r lifecycle::badge("deprecated")` Please use the `num_pt_year` argument instead.
+#' @param num_pt_year (`numeric(1)`)\cr number of patient-years to use when calculating adverse event rates.
 #'
 #' @return A list of components with the same names as the arguments.
 #'
@@ -25,22 +23,7 @@
 control_incidence_rate <- function(conf_level = 0.95,
                                    conf_type = c("normal", "normal_log", "exact", "byar"),
                                    input_time_unit = c("year", "day", "week", "month"),
-                                   num_pt_year = 100,
-                                   time_unit_input = lifecycle::deprecated(),
-                                   time_unit_output = lifecycle::deprecated()) {
-  if (lifecycle::is_present(time_unit_input)) {
-    lifecycle::deprecate_warn(
-      "0.8.3", "control_incidence_rate(time_unit_input)", "control_incidence_rate(input_time_unit)"
-    )
-    input_time_unit <- time_unit_input
-  }
-  if (lifecycle::is_present(time_unit_output)) {
-    lifecycle::deprecate_warn(
-      "0.8.3", "control_incidence_rate(time_unit_output)", "control_incidence_rate(num_pt_year)"
-    )
-    num_pt_year <- time_unit_output
-  }
-
+                                   num_pt_year = 100) {
   conf_type <- match.arg(conf_type)
   input_time_unit <- match.arg(input_time_unit)
   checkmate::assert_number(num_pt_year)
