@@ -19,7 +19,7 @@
 #'   used to select the specific ANCOVA results. if the interaction is not needed, the default option is `FALSE`.
 #' @param .stats (`character`)\cr statistics to select for the table.
 #'
-#'   Options are: ``r shQuote(get_stats("summarize_ancova"))``
+#'   Options are: ``r shQuote(get_stats("summarize_ancova"), type = "sh")``
 #'
 #' @name summarize_ancova
 #' @order 1
@@ -38,6 +38,7 @@ NULL
 #'     interaction terms indicated by `"X1 * X2"`.
 #' @param interaction_item (`string` or `NULL`)\cr name of the variable that should have interactions
 #'   with arm. if the interaction is not needed, the default option is `NULL`.
+#' @param weights_emmeans (`string` or `NULL`)\cr argument from [emmeans::emmeans()]
 #'
 #' @return The summary of a linear model.
 #'
@@ -52,7 +53,8 @@ NULL
 h_ancova <- function(.var,
                      .df_row,
                      variables,
-                     interaction_item = NULL) {
+                     interaction_item = NULL,
+                     weights_emmeans = NULL) {
   checkmate::assert_string(.var)
   checkmate::assert_list(variables)
   checkmate::assert_subset(names(variables), c("arm", "covariates"))
@@ -88,7 +90,8 @@ h_ancova <- function(.var,
     # Specify here the group variable over which EMM are desired.
     specs = specs,
     # Pass the data again so that the factor levels of the arm variable can be inferred.
-    data = .df_row
+    data = .df_row,
+    weights = weights_emmeans
   )
 
   emmeans_fit
@@ -111,13 +114,21 @@ h_ancova <- function(.var,
 s_ancova <- function(df,
                      .var,
                      .df_row,
-                     variables,
                      .ref_group,
                      .in_ref_col,
+                     variables,
                      conf_level,
                      interaction_y = FALSE,
-                     interaction_item = NULL) {
-  emmeans_fit <- h_ancova(.var = .var, variables = variables, .df_row = .df_row, interaction_item = interaction_item)
+                     interaction_item = NULL,
+                     weights_emmeans = NULL,
+                     ...) {
+  emmeans_fit <- h_ancova(
+    .var = .var,
+    variables = variables,
+    .df_row = .df_row,
+    interaction_item = interaction_item,
+    weights_emmeans = weights_emmeans
+  )
 
   sum_fit <- summary(
     emmeans_fit,
@@ -154,9 +165,9 @@ s_ancova <- function(df,
     list(
       n = length(y[!is.na(y)]),
       lsmean = formatters::with_label(sum_fit_level$emmean, "Adjusted Mean"),
-      lsmean_diff = formatters::with_label(character(), "Difference in Adjusted Means"),
-      lsmean_diff_ci = formatters::with_label(character(), f_conf_level(conf_level)),
-      pval = formatters::with_label(character(), "p-value")
+      lsmean_diff = formatters::with_label(numeric(), "Difference in Adjusted Means"),
+      lsmean_diff_ci = formatters::with_label(numeric(), f_conf_level(conf_level)),
+      pval = formatters::with_label(numeric(), "p-value")
     )
   } else {
     # Estimate the differences between the marginal means.
@@ -207,18 +218,62 @@ s_ancova <- function(df,
 #' * `a_ancova()` returns the corresponding list with formatted [rtables::CellValue()].
 #'
 #' @keywords internal
-a_ancova <- make_afun(
-  s_ancova,
-  .indent_mods = c("n" = 0L, "lsmean" = 0L, "lsmean_diff" = 0L, "lsmean_diff_ci" = 1L, "pval" = 1L),
-  .formats = c(
-    "n" = "xx",
-    "lsmean" = "xx.xx",
-    "lsmean_diff" = "xx.xx",
-    "lsmean_diff_ci" = "(xx.xx, xx.xx)",
-    "pval" = "x.xxxx | (<0.0001)"
-  ),
-  .null_ref_cells = FALSE
-)
+a_ancova <- function(df,
+                     ...,
+                     .stats = NULL,
+                     .stat_names = NULL,
+                     .formats = NULL,
+                     .labels = NULL,
+                     .indent_mods = NULL) {
+  # Check for additional parameters to the statistics function
+  dots_extra_args <- list(...)
+  extra_afun_params <- retrieve_extra_afun_params(names(dots_extra_args$.additional_fun_parameters))
+  dots_extra_args$.additional_fun_parameters <- NULL
+
+  # Check for user-defined functions
+  default_and_custom_stats_list <- .split_std_from_custom_stats(.stats)
+  .stats <- default_and_custom_stats_list$all_stats
+  custom_stat_functions <- default_and_custom_stats_list$custom_stats
+
+  # Apply statistics function
+  x_stats <- .apply_stat_functions(
+    default_stat_fnc = s_ancova,
+    custom_stat_fnc_list = custom_stat_functions,
+    args_list = c(
+      df = list(df),
+      extra_afun_params,
+      dots_extra_args
+    )
+  )
+
+  # Fill in formatting defaults
+  .stats <- get_stats("summarize_ancova",
+    stats_in = .stats,
+    custom_stats_in = names(custom_stat_functions)
+  )
+  x_stats <- x_stats[.stats]
+  .formats <- get_formats_from_stats(.stats, .formats)
+  .labels <- get_labels_from_stats(
+    .stats, .labels,
+    tern_defaults = c(lapply(x_stats[names(x_stats) != "n"], attr, "label"), tern_default_labels)
+  )
+  .indent_mods <- get_indents_from_stats(.stats, .indent_mods)
+
+  # Auto format handling
+  .formats <- apply_auto_formatting(.formats, x_stats, extra_afun_params$.df_row, extra_afun_params$.var)
+
+  # Get and check statistical names
+  .stat_names <- get_stat_names(x_stats, .stat_names)
+
+  in_rows(
+    .list = x_stats,
+    .formats = .formats,
+    .names = .labels %>% .unlist_keep_nulls(),
+    .stat_names = .stat_names,
+    .labels = .labels %>% .unlist_keep_nulls(),
+    .indent_mods = .indent_mods %>% .unlist_keep_nulls()
+  )
+}
 
 #' @describeIn summarize_ancova Layout-creating function which can take statistics function arguments
 #'   and additional format arguments. This function is a wrapper for [rtables::analyze()].
@@ -255,40 +310,47 @@ summarize_ancova <- function(lyt,
                              conf_level,
                              interaction_y = FALSE,
                              interaction_item = NULL,
+                             weights_emmeans = NULL,
                              var_labels,
                              na_str = default_na_str(),
                              nested = TRUE,
                              ...,
                              show_labels = "visible",
                              table_names = vars,
-                             .stats = NULL,
+                             .stats = c("n", "lsmean", "lsmean_diff", "lsmean_diff_ci", "pval"),
+                             .stat_names = NULL,
                              .formats = NULL,
                              .labels = NULL,
-                             .indent_mods = NULL) {
-  extra_args <- list(
-    variables = variables, conf_level = conf_level, interaction_y = interaction_y,
-    interaction_item = interaction_item, ...
+                             .indent_mods = list("lsmean_diff_ci" = 1L, "pval" = 1L)) {
+  # Process standard extra arguments
+  extra_args <- list(".stats" = .stats)
+  if (!is.null(.stat_names)) extra_args[[".stat_names"]] <- .stat_names
+  if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
+  if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
+  if (!is.null(.indent_mods)) extra_args[[".indent_mods"]] <- .indent_mods
+
+  # Process additional arguments to the statistic function
+  extra_args <- c(
+    extra_args,
+    variables = list(variables), conf_level = list(conf_level), interaction_y = list(interaction_y),
+    interaction_item = list(interaction_item),
+    weights_emmeans = weights_emmeans,
+    ...
   )
 
-  afun <- make_afun(
-    a_ancova,
-    interaction_y = interaction_y,
-    interaction_item = interaction_item,
-    .stats = .stats,
-    .formats = .formats,
-    .labels = .labels,
-    .indent_mods = .indent_mods
-  )
+  # Append additional info from layout to the analysis function
+  extra_args[[".additional_fun_parameters"]] <- get_additional_afun_params(add_alt_df = FALSE)
+  formals(a_ancova) <- c(formals(a_ancova), extra_args[[".additional_fun_parameters"]])
 
   analyze(
-    lyt,
-    vars,
-    var_labels = var_labels,
-    show_labels = show_labels,
-    table_names = table_names,
-    afun = afun,
+    lyt = lyt,
+    vars = vars,
+    afun = a_ancova,
     na_str = na_str,
     nested = nested,
-    extra_args = extra_args
+    extra_args = extra_args,
+    var_labels = var_labels,
+    show_labels = show_labels,
+    table_names = table_names
   )
 }
