@@ -21,7 +21,7 @@
 #'   for that statistic's row label.
 #' @param .stats (`character`)\cr statistics to select for the table.
 #'
-#'   Options are: ``r shQuote(get_stats("surv_time"))``
+#'   Options are: ``r shQuote(get_stats("surv_time"), type = "sh")``
 #'
 #' @examples
 #' library(dplyr)
@@ -55,6 +55,7 @@ NULL
 #' @keywords internal
 s_surv_time <- function(df,
                         .var,
+                        ...,
                         is_event,
                         control = control_surv_time()) {
   checkmate::assert_string(.var)
@@ -135,51 +136,54 @@ s_surv_time <- function(df,
 #' @export
 a_surv_time <- function(df,
                         labelstr = "",
-                        .var = NULL,
-                        .df_row = NULL,
-                        is_event,
-                        control = control_surv_time(),
-                        ref_fn_censor = TRUE,
+                        ...,
                         .stats = NULL,
+                        .stat_names = NULL,
                         .formats = NULL,
                         .labels = NULL,
-                        .indent_mods = NULL,
-                        na_str = default_na_str()) {
-  x_stats <- s_surv_time(
-    df = df, .var = .var, is_event = is_event, control = control
+                        .indent_mods = NULL) {
+  # Check for additional parameters to the statistics function
+  dots_extra_args <- list(...)
+  extra_afun_params <- retrieve_extra_afun_params(names(dots_extra_args$.additional_fun_parameters))
+  dots_extra_args$.additional_fun_parameters <- NULL
+
+  # Check for user-defined functions
+  default_and_custom_stats_list <- .split_std_from_custom_stats(.stats)
+  .stats <- default_and_custom_stats_list$all_stats
+  custom_stat_functions <- default_and_custom_stats_list$custom_stats
+
+  # Main statistic calculations
+  x_stats <- .apply_stat_functions(
+    default_stat_fnc = s_surv_time,
+    custom_stat_fnc_list = custom_stat_functions,
+    args_list = c(
+      df = list(df),
+      labelstr = list(labelstr),
+      extra_afun_params,
+      dots_extra_args
+    )
   )
+
   rng_censor_lwr <- x_stats[["range_censor"]][1]
   rng_censor_upr <- x_stats[["range_censor"]][2]
 
-  # Use method-specific defaults
-  fmts <- c(
-    median_ci = "(xx.x, xx.x)", quantiles = "xx.x, xx.x", range = "xx.x to xx.x",
-    median_ci_3d = "xx.x (xx.x - xx.x)",
-    quantiles_lower = "xx.x (xx.x - xx.x)", quantiles_upper = "xx.x (xx.x - xx.x)"
-  )
-  lbls <- c(
-    median_ci = "95% CI", range = "Range", range_censor = "Range (censored)", range_event = "Range (event)",
-    median_ci_3d = "Median (95% CI)",
-    quantiles_lower = "25%-ile (95% CI)",
-    quantiles_upper = "75%-ile (95% CI)"
-  )
-  lbls_custom <- .labels
-  .formats <- c(.formats, fmts[setdiff(names(fmts), names(.formats))])
-  .labels <- c(.labels, lbls[setdiff(names(lbls), names(lbls_custom))])
-
-  # Fill in with formatting defaults if needed
-  .stats <- get_stats("surv_time", stats_in = .stats)
+  # Fill in formatting defaults
+  .stats <- get_stats("surv_time", stats_in = .stats, custom_stats_in = names(custom_stat_functions))
   .formats <- get_formats_from_stats(.stats, .formats)
-  .labels <- get_labels_from_stats(.stats, .labels) %>% labels_use_control(control, lbls_custom)
+  .labels <- get_labels_from_stats(.stats, .labels) %>% labels_use_control(dots_extra_args$control)
   .indent_mods <- get_indents_from_stats(.stats, .indent_mods)
 
   x_stats <- x_stats[.stats]
 
   # Auto format handling
-  .formats <- apply_auto_formatting(.formats, x_stats, .df_row, .var)
+  .formats <- apply_auto_formatting(.formats, x_stats, extra_afun_params$.df_row, extra_afun_params$.var)
 
-  cell_fns <- setNames(vector("list", length = length(x_stats)), .labels)
-  if ("range" %in% names(x_stats) && ref_fn_censor) {
+  # Get and check statistical names
+  .stat_names <- get_stat_names(x_stats, .stat_names)
+
+  # Get cell footnotes
+  cell_fns <- stats::setNames(vector("list", length = length(x_stats)), .labels)
+  if ("range" %in% names(x_stats) && "ref_fn_censor" %in% names(dots_extra_args) && dots_extra_args$ref_fn_censor) {
     if (identical(x_stats[["range"]][1], rng_censor_lwr) && identical(x_stats[["range"]][2], rng_censor_upr)) {
       cell_fns[[.labels[["range"]]]] <- "Censored observations: range minimum & maximum"
     } else if (identical(x_stats[["range"]][1], rng_censor_lwr)) {
@@ -192,9 +196,10 @@ a_surv_time <- function(df,
   in_rows(
     .list = x_stats,
     .formats = .formats,
-    .names = .labels,
-    .labels = .labels,
-    .indent_mods = .indent_mods,
+    .names = names(.labels),
+    .stat_names = .stat_names,
+    .labels = .labels %>% .unlist_keep_nulls(),
+    .indent_mods = .indent_mods %>% .unlist_keep_nulls(),
     .cell_footnotes = cell_fns
   )
 }
@@ -233,14 +238,32 @@ surv_time <- function(lyt,
                       show_labels = "visible",
                       table_names = vars,
                       .stats = c("median", "median_ci", "quantiles", "range"),
-                      .formats = NULL,
-                      .labels = NULL,
-                      .indent_mods = c(median_ci = 1L)) {
-  extra_args <- list(
-    .stats = .stats, .formats = .formats, .labels = .labels, .indent_mods = .indent_mods,
-    is_event = is_event, control = control, ref_fn_censor = ref_fn_censor, ...
+                      .stat_names = NULL,
+                      .formats = list(
+                        median_ci = "(xx.x, xx.x)", quantiles = "xx.x, xx.x", range = "xx.x to xx.x",
+                        quantiles_lower = "xx.x (xx.x - xx.x)", quantiles_upper = "xx.x (xx.x - xx.x)",
+                        median_ci_3d = "xx.x (xx.x - xx.x)"
+                      ),
+                      .labels = list(median_ci = "95% CI", range = "Range"),
+                      .indent_mods = list(median_ci = 1L)) {
+  # Process standard extra arguments
+  extra_args <- list(".stats" = .stats)
+  if (!is.null(.stat_names)) extra_args[[".stat_names"]] <- .stat_names
+  if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
+  if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
+  if (!is.null(.indent_mods)) extra_args[[".indent_mods"]] <- .indent_mods
+
+  # Process additional arguments to the statistic function
+  extra_args <- c(
+    extra_args,
+    is_event = is_event, control = list(control), ref_fn_censor = ref_fn_censor,
+    ...
   )
 
+  # Adding additional info from layout to analysis function
+  extra_args[[".additional_fun_parameters"]] <- get_additional_afun_params(add_alt_df = FALSE)
+  formals(a_surv_time) <- c(formals(a_surv_time), extra_args[[".additional_fun_parameters"]])
+
   analyze(
     lyt = lyt,
     vars = vars,
