@@ -123,3 +123,81 @@ testthat::test_that("text wrapping works as expected", {
 
   expect_snapshot_ggplot(title = "deco_grob_text_wrap", fig = deco_grob_text_wrap, width = 10, height = 8)
 })
+
+testthat::test_that("Edge cases work for titles and footers in split_text_grob", {
+  # regression test #1254
+  testthat::expect_silent(
+    split_text_grob(NULL)
+  )
+  testthat::expect_silent(
+    split_text_grob("")
+  )
+  testthat::expect_silent(
+    split_text_grob(c("", NA))
+  )
+  testthat::expect_silent(
+    split_text_grob(NA)
+  )
+  testthat::expect_silent(
+    split_text_grob(c("", "a a"))
+  )
+})
+
+testthat::test_that("Wrapping works consistently", {
+  # ggplot
+  g <- ggplot2::ggplot(iris) +
+    ggplot2::geom_point(aes(x = Sepal.Length, y = Sepal.Width))
+
+  # decoration text
+  eg_text <- c(
+    paste( # titles
+      rep("issues come in long pairs", 10),
+      collapse = " "
+    ),
+    c( # subtitles
+      "something\nwith\\n", "", "and such"
+    )
+  )
+  # example width (it is default for A4 with 1.5cm margin)
+  eg_width <- grid::unit(11.63, "inches") - grid::unit(1.5, "cm")
+
+  # Main call to text grob split
+  out <- split_text_grob(eg_text,
+    x = 0, y = 1,
+    just = c("left", "top"),
+    width = eg_width,
+    vp = grid::viewport(layout.pos.row = 1, layout.pos.col = 1),
+    gp = grid::gpar()
+  )
+
+  # This is what (roughly w/o font correction from gpar) happens inside the split
+  eg_width <- grid::convertUnit(eg_width, "npc")
+  # Fix for split_string in case of residual \n (otherwise is counted as character)
+  text_fin <- split_string( # copied fnc (NOT formatters')
+    unlist(
+      strsplit(
+        paste0(gsub("\\\\n", "\n", eg_text), collapse = "\n"), # for "" cases
+        "\n"
+      )
+    ),
+    eg_width
+  )
+
+  # number of characters
+  nchar_lab_extracted <- nchar(strsplit(out$label, "\n")[[1]])
+  nchar_lab_test <- nchar(strsplit(text_fin, "\n")[[1]])
+  exp_nchar_lab <- c(144, 114, 9, 4, 0, 0, 8)
+
+  # Force informative error
+  if (!checkmate::check_set_equal(nchar_lab_extracted, exp_nchar_lab)) {
+    stop(
+      "width:", eg_width,
+      "\nnchar_out_label  : ", paste(nchar_lab_extracted, collapse = " "),
+      "\nnchar_label_free : ", paste(nchar_lab_test, collapse = " ")
+    )
+  }
+
+  # Default passing tests
+  testthat::expect_equal(nchar_lab_extracted, nchar_lab_test)
+  testthat::expect_equal(nchar_lab_extracted, exp_nchar_lab)
+})
